@@ -1271,8 +1271,8 @@ class BaseGraph(GraphReadWrite):
             neighbour_ids = self._get_lst(None, key)
             if has_cache:
                 _cache[cache_key] = neighbour_ids
-        # Special case when filters is empty :
-        if not filters:
+        # Special case when filters is empty or kind is edge (no need to look in index in the case of edge)
+        if (_kind == KIND_EDGE) or not filters:
             for entity_id in iter(neighbour_ids):
                 yield entity_id
         else:
