@@ -8,7 +8,6 @@ import json
 
 from grapheekdb.lib.undef import UNDEFINED
 
-#from grapheekdb.backends.data.keys import METADATA_VERTEX_INDEX_PREFIX, METADATA_EDGE_INDEX_PREFIX
 from grapheekdb.backends.data.keys import FORBIDDEN_KEY
 from grapheekdb.backends.data.keys import CHUNK_SIZE
 from grapheekdb.backends.data.keys import COUNT_SUFFIX
@@ -31,7 +30,7 @@ class BaseIndex(object):
         self._kind = _kind
         self._prefix = _prefix
 
-    def build(self, txn, id_iterator):
+    def bulk_add(self, txn, id_iterator):
         raise NotImplementedError
 
     def add(self, txn, entity_id, data):
@@ -57,7 +56,13 @@ class ExactIndex(BaseIndex):
         self._filter_funcs = build_filter_funcs(**filters)
         self._fields.sort()
 
-    def build(self, txn, id_iterator):
+    def delete(self, txn):
+        """
+        delete the index
+        """
+        self._graph._remove_prefix(txn, self._prefix)
+
+    def bulk_add(self, txn, id_iterator):
 
         def save_lst(txn, chunk_idx, value, lst):
             lst_key = build_key(self._prefix, chunk_idx, value)
@@ -82,9 +87,10 @@ class ExactIndex(BaseIndex):
         for value, entity_ids in values_to_id.iteritems():
             lst = []
             value_count_key = build_key(self._prefix, COUNT_SUFFIX, value)
-            value_count = 0
-            self._graph._set(txn, value_count_key, 0)
-            chunk_idx = 0
+            value_count = self._graph._get(txn, value_count_key)
+            if value_count == UNDEFINED:
+                value_count = 0
+            chunk_idx = value_count / CHUNK_SIZE
             for entity_id in entity_ids:
                 value_count += 1
                 entity_dict[build_key(self._prefix, entity_id)] = build_key(chunk_idx, value)  # Need to keep an info of relation between entity and the chunk id that contains it
@@ -98,9 +104,6 @@ class ExactIndex(BaseIndex):
             self._graph._set(txn, value_count_key, value_count)
         self._graph._bulk_set(txn, entity_dict)
 
-    def delete(self, txn):
-        self._graph._remove_prefix(txn, self._prefix)
-
     def add(self, txn, entity_id, data):
         if self._filter_length and not entity_match(self._filter_funcs, data):
             return
@@ -132,9 +135,13 @@ class ExactIndex(BaseIndex):
             self._graph._remove(txn, entity_chunk_sub_key)
 
     def _compatible_filters(self, filters):
+        try:
+            set_filter_items = set(filters.items())
+        except TypeError:
+            return False
         # 1st : check that filters is compatible with (partial) index filters
         if self._filter_length:
-            if len(self._filter_items.intersection(set(filters.items()))) != self._filter_length:
+            if len(self._filter_items.intersection(set_filter_items)) != self._filter_length:
                 return False
         # 2nd, check on exact filters
         exact_filters = get_exact_filters(**filters)
