@@ -48,6 +48,16 @@ def unmarshall(graph, item):
     raise GrapheekUnmarshallingException('Unknown type %s' % type(item))
 
 
+def sanitize(item):
+    if isinstance(item, (BooleanType, FloatType, IntType, LongType, NoneType, StringType, UnicodeType)):
+        return item
+    if isinstance(item, (DictType)):
+        items = [(sanitize(key), sanitize(value)) for key, value in item.items()]
+        return dict(items)
+    elif isinstance(item, (ListType, TupleType, set)):
+        return [sanitize(x) for x in item]
+
+
 def check_proxy_node(entity):
     if not(isinstance(entity, ProxyNode)):
         raise GrapheekInvalidDataTypeException('%s is not a node')
@@ -306,7 +316,7 @@ class ProxyGraph(GraphReadWrite):
         self._zmq_socket.connect(address)
 
     def _request(self, commands):
-        data = msgpack.dumps(commands)
+        data = msgpack.dumps(sanitize(commands))
         self._zmq_socket.send(data)
         raw = self._zmq_socket.recv()
         msg = msgpack.loads(raw)
@@ -360,9 +370,9 @@ class ProxyGraph(GraphReadWrite):
         command = ['bulk_add_edge_by_ids', args, {'silent': silent}]
         return self._request([command])
 
-    def _add_entity_index(self, kind, *args, **filters):
-        assert(kind in (KIND_EDGE, KIND_VERTEX))
-        command = ['add_node_index' if kind == KIND_VERTEX else 'add_edge_index', args, filters]
+    def _add_entity_index(self, _kind, *args, **filters):
+        assert(_kind in (KIND_EDGE, KIND_VERTEX))
+        command = ['add_node_index' if _kind == KIND_VERTEX else 'add_edge_index', args, filters]
         return self._request([command])
 
     def add_node_index(self, *fields, **filters):
@@ -379,9 +389,9 @@ class ProxyGraph(GraphReadWrite):
         command = ['get_edge_indexes', [], {}]
         return self._request([command])
 
-    def _remove_entity_index(self, kind, *args):
-        assert(kind in (KIND_EDGE, KIND_VERTEX))
-        command = ['remove_node_index' if kind == KIND_VERTEX else 'remove_edge_index', args, {}]
+    def _remove_entity_index(self, _kind, *args):
+        assert(_kind in (KIND_EDGE, KIND_VERTEX))
+        command = ['remove_node_index' if _kind == KIND_VERTEX else 'remove_edge_index', args, {}]
         return self._request([command])
 
     def remove_node_index(self, *args):
